You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@netbeans.apache.org by bw...@apache.org on 2022/10/16 23:30:07 UTC

[netbeans] branch master updated: Cleanup more raw type List warnings.. (#4794)

This is an automated email from the ASF dual-hosted git repository.

bwalker pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/netbeans.git


The following commit(s) were added to refs/heads/master by this push:
     new ee5492da33 Cleanup more raw type List warnings.. (#4794)
ee5492da33 is described below

commit ee5492da3360481aa5fb82c54848d03d2910582f
Author: Brad Walker <bw...@musings.com>
AuthorDate: Sun Oct 16 19:29:58 2022 -0400

    Cleanup more raw type List warnings.. (#4794)
    
    Cleanup more raw type List warnings that look like this:
    
       [repeat] /home/bwalker/src/netbeans/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/client/ClientDataObject.java:174: warning: [rawtypes] found raw type: List
       [repeat]                     java.util.List changes = null;
       [repeat]                              ^
       [repeat]   missing type arguments for generic class List<E>
       [repeat]   where E is a type-variable:
       [repeat]     E extends Object declared in interface List
    
    Also, removed ComplexValueSettingsFactory as it's not exported and unused in the module.
---
 .../AppClientProjectWebServicesClientSupport.java  |  4 +-
 .../j2ee/ddloaders/client/ClientDataObject.java    |  4 +-
 .../ddloaders/common/xmlutils/XMLJ2eeUtils.java    | 46 ++++++++++++----------
 .../EjbJarWebServicesClientSupport.java            |  6 +--
 .../ejbjarproject/EjbJarWebServicesSupport.java    | 10 ++---
 .../j2ee/ejbjarproject/UpdateProjectImpl.java      |  6 +--
 .../netbeans/modules/j2ee/ejbjarproject/Utils.java |  2 +-
 .../eecommon/api/JDBCDriverDeployHelper.java       |  4 +-
 .../modules/web/freeform/WebProjectGenerator.java  |  4 +-
 .../modules/web/project/WebActionProvider.java     |  2 +-
 .../WebProjectWebServicesClientSupport.java        |  4 +-
 .../web/project/WebProjectWebServicesSupport.java  |  8 ++--
 .../api/client/WsCompileClientEditorSupport.java   |  8 ++--
 .../spi/jaxws/client/JAXWSClientSupportImpl.java   | 36 +++++++++--------
 .../jaxws/client/ProjectJAXWSClientSupport.java    |  4 +-
 .../websvc/manager/model/WebServiceListModel.java  |  2 +-
 .../websvc/api/webservices/WebServicesSupport.java |  2 +-
 .../spi/webservices/WebServicesSupportImpl.java    |  3 +-
 .../groovy/editor/actions/FixImportsAction.java    |  7 ++--
 .../visualeditor/querybuilder/QueryBuilder.java    |  4 +-
 .../querybuilder/QueryBuilderGraphFrame.java       |  2 +-
 .../querybuilder/QueryBuilderMetaData.java         | 46 +++-------------------
 .../xml/api/model/ExtendedGrammarQuery.java        |  2 +-
 .../modules/xml/dtd/grammar/DTDGrammar.java        |  6 +--
 .../obsolete90/ComplexValueSettingsFactory.java    | 38 ------------------
 .../xml/text/completion/GrammarManager.java        |  4 +-
 .../completion/ETCompletionContextResolver.java    |  7 ++--
 .../entitygenerator/CMPMappingModel.java           |  2 +-
 .../java/freeform/JavaProjectGenerator.java        |  2 +-
 .../grammar/effpom/AnnotationMarkProvider.java     |  2 +-
 .../openide/util/DefaultMutexImplementation.java   |  5 +--
 .../org/openide/util/TopologicalSortException.java |  2 +-
 .../lib/profiler/ui/components/JTreeTable.java     |  4 +-
 .../treetable/TreeTableModelAdapter.java           | 12 +++---
 .../profiler/heapwalk/ClassesController.java       |  8 ++--
 .../profiler/heapwalk/FieldsBrowserController.java |  2 +-
 .../profiler/heapwalk/InstancesController.java     | 14 +++----
 .../heapwalk/ReferencesBrowserController.java      |  2 +-
 .../profiler/heapwalk/model/BrowserUtils.java      |  4 +-
 .../heapwalk/ui/FieldsBrowserControllerUI.java     |  6 +--
 .../heapwalk/ui/ReferencesBrowserControllerUI.java |  2 +-
 41 files changed, 135 insertions(+), 203 deletions(-)

diff --git a/enterprise/j2ee.clientproject/src/org/netbeans/modules/j2ee/clientproject/wsclient/AppClientProjectWebServicesClientSupport.java b/enterprise/j2ee.clientproject/src/org/netbeans/modules/j2ee/clientproject/wsclient/AppClientProjectWebServicesClientSupport.java
index 861c3186c4..bc4ff8474a 100644
--- a/enterprise/j2ee.clientproject/src/org/netbeans/modules/j2ee/clientproject/wsclient/AppClientProjectWebServicesClientSupport.java
+++ b/enterprise/j2ee.clientproject/src/org/netbeans/modules/j2ee/clientproject/wsclient/AppClientProjectWebServicesClientSupport.java
@@ -530,7 +530,7 @@ public class AppClientProjectWebServicesClientSupport implements WebServicesClie
         "donotunwrap", // - portable // NOI18N
     };
     
-    private static final List allClientFeatures = Arrays.asList(WSCOMPILE_CLIENT_FEATURES);
+    private static final List<String> allClientFeatures = Arrays.asList(WSCOMPILE_CLIENT_FEATURES);
     
     private static final String [] WSCOMPILE_KEY_CLIENT_FEATURES = {
         "wsi", // NOI18N
@@ -545,7 +545,7 @@ public class AppClientProjectWebServicesClientSupport implements WebServicesClie
         "searchschema", // NOI18N
     };
     
-    private static final List importantClientFeatures = Arrays.asList(WSCOMPILE_KEY_CLIENT_FEATURES);
+    private static final List<String> importantClientFeatures = Arrays.asList(WSCOMPILE_KEY_CLIENT_FEATURES);
     
     public List<WsCompileClientEditorSupport.ServiceSettings> getServiceClients() {
         List<WsCompileClientEditorSupport.ServiceSettings> serviceNames = new ArrayList<WsCompileClientEditorSupport.ServiceSettings>();
diff --git a/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/client/ClientDataObject.java b/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/client/ClientDataObject.java
index 5c115a69f9..5a7d146f0b 100644
--- a/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/client/ClientDataObject.java
+++ b/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/client/ClientDataObject.java
@@ -171,7 +171,7 @@ public class ClientDataObject extends  DDMultiViewDataObject
         if (updateTask == null) {
             updateTask = RequestProcessor.getDefault().post(new Runnable() {
                 public void run() {
-                    java.util.List changes = null;
+                    List<DDChangeEvent> changes = null;
                     synchronized (ClientDataObject.this) {
                         if (!ClientDataObject.this.isValid()) {
                             return;
@@ -277,7 +277,7 @@ public class ClientDataObject extends  DDMultiViewDataObject
     }
 
     
-    private void showDDChangesDialog(List changes) {
+    private void showDDChangesDialog(List<DDChangeEvent> changes) {
         final JButton processButton;
         final JButton processAllButton;
         final JButton closeButton;
diff --git a/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/EjbJarWebServicesClientSupport.java b/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/EjbJarWebServicesClientSupport.java
index c0c5e6600d..446062233c 100644
--- a/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/EjbJarWebServicesClientSupport.java
+++ b/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/EjbJarWebServicesClientSupport.java
@@ -572,7 +572,7 @@ public class EjbJarWebServicesClientSupport implements WebServicesClientSupportI
         "donotunwrap", // - portable // NOI18N
     };
     
-    private static final List allClientFeatures = Arrays.asList(WSCOMPILE_CLIENT_FEATURES);
+    private static final List<String> allClientFeatures = Arrays.asList(WSCOMPILE_CLIENT_FEATURES);
     
     private static final String [] WSCOMPILE_KEY_CLIENT_FEATURES = {
         "wsi",
@@ -587,9 +587,9 @@ public class EjbJarWebServicesClientSupport implements WebServicesClientSupportI
         "searchschema",
     };
     
-    private static final List importantClientFeatures = Arrays.asList(WSCOMPILE_KEY_CLIENT_FEATURES);
+    private static final List<String> importantClientFeatures = Arrays.asList(WSCOMPILE_KEY_CLIENT_FEATURES);
     
-    public List getServiceClients() {
+    public List<WsCompileClientEditorSupport.ServiceSettings> getServiceClients() {
         List<WsCompileClientEditorSupport.ServiceSettings> serviceNames = new ArrayList<WsCompileClientEditorSupport.ServiceSettings>();
         
         Element data = helper.getPrimaryConfigurationData(true);
diff --git a/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/EjbJarWebServicesSupport.java b/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/EjbJarWebServicesSupport.java
index 67349c79ce..360dda60af 100644
--- a/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/EjbJarWebServicesSupport.java
+++ b/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/EjbJarWebServicesSupport.java
@@ -442,7 +442,7 @@ public class EjbJarWebServicesSupport implements WebServicesSupportImpl{
         //        "donotunwrap", // WSDL - portable
     };
     
-    private static final List allSeiServiceFeatures = Arrays.asList(WSCOMPILE_SEI_SERVICE_FEATURES);
+    private static final List<String> allSeiServiceFeatures = Arrays.asList(WSCOMPILE_SEI_SERVICE_FEATURES);
     
     private static final String [] WSCOMPILE_KEY_SEI_SERVICE_FEATURES = {
         "documentliteral",
@@ -452,7 +452,7 @@ public class EjbJarWebServicesSupport implements WebServicesSupportImpl{
         "donotoverride"
     };
     
-    private static final List importantSeiServiceFeatures = Arrays.asList(WSCOMPILE_KEY_SEI_SERVICE_FEATURES);
+    private static final List<String> importantSeiServiceFeatures = Arrays.asList(WSCOMPILE_KEY_SEI_SERVICE_FEATURES);
     
     private static final String [] WSCOMPILE_WSDL_SERVICE_FEATURES = {
         "datahandleronly", // WSDL - portable
@@ -477,7 +477,7 @@ public class EjbJarWebServicesSupport implements WebServicesSupportImpl{
         "donotunwrap", // WSDL - portable
     };
     
-    private static final List allWsdlServiceFeatures = Arrays.asList(WSCOMPILE_WSDL_SERVICE_FEATURES);
+    private static final List<String> allWsdlServiceFeatures = Arrays.asList(WSCOMPILE_WSDL_SERVICE_FEATURES);
     
     private static final String [] WSCOMPILE_KEY_WSDL_SERVICE_FEATURES = {
         "datahandleronly",
@@ -492,9 +492,9 @@ public class EjbJarWebServicesSupport implements WebServicesSupportImpl{
         "donotunwrap"
     };
     
-    private static final List importantWsdlServiceFeatures = Arrays.asList(WSCOMPILE_KEY_WSDL_SERVICE_FEATURES);
+    private static final List<String> importantWsdlServiceFeatures = Arrays.asList(WSCOMPILE_KEY_WSDL_SERVICE_FEATURES);
     
-    public List/*WsCompileEditorSupport.ServiceSettings*/ getServices() {
+    public List<WsCompileEditorSupport.ServiceSettings> getServices() {
         List<WsCompileEditorSupport.ServiceSettings> serviceList = new ArrayList<WsCompileEditorSupport.ServiceSettings>();
         
         // Implementation from getServiceClients() -- FIXME
diff --git a/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/UpdateProjectImpl.java b/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/UpdateProjectImpl.java
index 87be69c076..f4fee87af9 100644
--- a/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/UpdateProjectImpl.java
+++ b/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/UpdateProjectImpl.java
@@ -192,9 +192,9 @@ public class UpdateProjectImpl implements UpdateImplementation {
                             String fileText = XMLUtil.findText(library);
                             if (fileText.startsWith ("libs.")) {
                                 String libName = fileText.substring(6, fileText.indexOf(".classpath")); //NOI18N
-                                List/*<URL>*/ roots = LibraryManager.getDefault().getLibrary(libName).getContent("classpath"); //NOI18N
-                                ArrayList<FileObject> files = new ArrayList<FileObject>();
-                                ArrayList<FileObject> dirs = new ArrayList<FileObject>();
+                                List<URL> roots = LibraryManager.getDefault().getLibrary(libName).getContent("classpath"); //NOI18N
+                                List<FileObject> files = new ArrayList<>();
+                                List<FileObject> dirs  = new ArrayList<>();
                                 for (Iterator<URL> it = roots.iterator(); it.hasNext();) {
                                     URL rootUrl = it.next();
                                     FileObject root = org.openide.filesystems.URLMapper.findFileObject (rootUrl);
diff --git a/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/Utils.java b/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/Utils.java
index 4b58edfdac..daec8a45cf 100644
--- a/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/Utils.java
+++ b/enterprise/j2ee.ejbjarproject/src/org/netbeans/modules/j2ee/ejbjarproject/Utils.java
@@ -118,7 +118,7 @@ public class Utils {
                         J2eeModuleProvider affectedPrjProvider1 = p1.getLookup().lookup(J2eeModuleProvider.class);
                         J2eeModuleProvider affectedPrjProvider2 = p2.getLookup().lookup(J2eeModuleProvider.class);
                         if (affectedPrjProvider1 != null && affectedPrjProvider2 != null) {
-                            List childModules = Arrays.asList(j2eeModules);
+                            List<J2eeModuleProvider> childModules = Arrays.asList(j2eeModules);
                             if (childModules.contains(affectedPrjProvider1) &&
                                 childModules.contains(affectedPrjProvider2)) {
                                 return true;
diff --git a/enterprise/payara.eecommon/src/org/netbeans/modules/payara/eecommon/api/JDBCDriverDeployHelper.java b/enterprise/payara.eecommon/src/org/netbeans/modules/payara/eecommon/api/JDBCDriverDeployHelper.java
index ef9e15ca21..7eae5d1732 100644
--- a/enterprise/payara.eecommon/src/org/netbeans/modules/payara/eecommon/api/JDBCDriverDeployHelper.java
+++ b/enterprise/payara.eecommon/src/org/netbeans/modules/payara/eecommon/api/JDBCDriverDeployHelper.java
@@ -56,7 +56,7 @@ import org.openide.util.NbBundle;
 
 public class JDBCDriverDeployHelper {
 
-    public static ProgressObject getProgressObject(File driverLoc, List listOfURLS) {
+    public static ProgressObject getProgressObject(File driverLoc, List<URL> listOfURLS) {
         return new JDBCDriversProgressObject(driverLoc, listOfURLS);
     }
 
@@ -151,7 +151,7 @@ public class JDBCDriverDeployHelper {
         private final File driverLoc;
         private List<URL> jdbcDriverURLs;
 
-        public JDBCDriversProgressObject(File driverLoc, List jdbcDriverURLs) {
+        public JDBCDriversProgressObject(File driverLoc, List<URL> jdbcDriverURLs) {
             eventSupport = new ProgressEventSupport(this); //JDBCDriverDeployHelper.this);
             String msg = NbBundle.getMessage(JDBCDriverDeployHelper.class, "MSG_CheckMissingDrivers");
             eventSupport.fireHandleProgressEvent(null, ProgressEventSupport.createStatus(ActionType.EXECUTE, CommandType.DISTRIBUTE, msg, StateType.RUNNING));
diff --git a/enterprise/web.freeform/src/org/netbeans/modules/web/freeform/WebProjectGenerator.java b/enterprise/web.freeform/src/org/netbeans/modules/web/freeform/WebProjectGenerator.java
index bc67008bc0..abaae97c03 100644
--- a/enterprise/web.freeform/src/org/netbeans/modules/web/freeform/WebProjectGenerator.java
+++ b/enterprise/web.freeform/src/org/netbeans/modules/web/freeform/WebProjectGenerator.java
@@ -85,7 +85,7 @@ public class WebProjectGenerator {
             foldersEl = doc.createElementNS(Util.NAMESPACE, "folders"); // NOI18N
             XMLUtil.appendChildElement(data, foldersEl, rootElementsOrder);
         } else {
-            List l = XMLUtil.findSubElements(foldersEl);
+            List<Element> l = XMLUtil.findSubElements(foldersEl);
             for (int i = 0; i < l.size(); i++) {
                 Element e = (Element) l.get(i);
                 Element te = XMLUtil.findElement(e, "type", Util.NAMESPACE);
@@ -106,7 +106,7 @@ public class WebProjectGenerator {
             itemsEl = doc.createElementNS(Util.NAMESPACE, "items"); // NOI18N
             XMLUtil.appendChildElement(viewEl, itemsEl, viewElementsOrder);
         } else {
-            List l = XMLUtil.findSubElements(itemsEl);
+            List<Element> l = XMLUtil.findSubElements(itemsEl);
             for (int i = 0; i < l.size(); i++) {
                 Element e = (Element) l.get(i);
                 if (e.hasAttribute("style")) {
diff --git a/enterprise/web.project/src/org/netbeans/modules/web/project/WebActionProvider.java b/enterprise/web.project/src/org/netbeans/modules/web/project/WebActionProvider.java
index 772d1deeec..c0fe75f757 100644
--- a/enterprise/web.project/src/org/netbeans/modules/web/project/WebActionProvider.java
+++ b/enterprise/web.project/src/org/netbeans/modules/web/project/WebActionProvider.java
@@ -429,7 +429,7 @@ public class WebActionProvider extends BaseActionProvider {
 
                     WebServicesSupport wss = WebServicesSupport.getWebServicesSupport(serverProject.getProjectDirectory());
                     if (wss != null) { //project contains ws
-                        List services = wss.getServices();
+                        List<WsCompileEditorSupport.ServiceSettings> services = wss.getServices();
                         boolean match = false;
                         for (Iterator sIt = services.iterator(); sIt.hasNext();) {
                             WsCompileEditorSupport.ServiceSettings serviceSettings =
diff --git a/enterprise/web.project/src/org/netbeans/modules/web/project/WebProjectWebServicesClientSupport.java b/enterprise/web.project/src/org/netbeans/modules/web/project/WebProjectWebServicesClientSupport.java
index 35024992e0..cd4ffdf806 100644
--- a/enterprise/web.project/src/org/netbeans/modules/web/project/WebProjectWebServicesClientSupport.java
+++ b/enterprise/web.project/src/org/netbeans/modules/web/project/WebProjectWebServicesClientSupport.java
@@ -630,7 +630,7 @@ public class WebProjectWebServicesClientSupport implements WebServicesClientSupp
         "donotunwrap", // - portable
     };
     
-    private static final List allClientFeatures = Arrays.asList(WSCOMPILE_CLIENT_FEATURES);
+    private static final List<String> allClientFeatures = Arrays.asList(WSCOMPILE_CLIENT_FEATURES);
     
     private static final String [] WSCOMPILE_KEY_CLIENT_FEATURES = {
         "wsi",
@@ -645,7 +645,7 @@ public class WebProjectWebServicesClientSupport implements WebServicesClientSupp
         "searchschema",
     };
     
-    private static final List importantClientFeatures = Arrays.asList(WSCOMPILE_KEY_CLIENT_FEATURES);
+    private static final List<String> importantClientFeatures = Arrays.asList(WSCOMPILE_KEY_CLIENT_FEATURES);
     
     public List<WsCompileClientEditorSupport.ServiceSettings> getServiceClients() {
         List<WsCompileClientEditorSupport.ServiceSettings> serviceNames = new ArrayList<WsCompileClientEditorSupport.ServiceSettings>();
diff --git a/enterprise/web.project/src/org/netbeans/modules/web/project/WebProjectWebServicesSupport.java b/enterprise/web.project/src/org/netbeans/modules/web/project/WebProjectWebServicesSupport.java
index d7346d881d..667419ff24 100644
--- a/enterprise/web.project/src/org/netbeans/modules/web/project/WebProjectWebServicesSupport.java
+++ b/enterprise/web.project/src/org/netbeans/modules/web/project/WebProjectWebServicesSupport.java
@@ -421,7 +421,7 @@ public class WebProjectWebServicesSupport implements WebServicesSupportImpl {
         //        "donotunwrap", // WSDL - portable
     };
     
-    private static final List allSeiServiceFeatures = Arrays.asList(WSCOMPILE_SEI_SERVICE_FEATURES);
+    private static final List<String> allSeiServiceFeatures = Arrays.asList(WSCOMPILE_SEI_SERVICE_FEATURES);
     
     private static final String [] WSCOMPILE_KEY_SEI_SERVICE_FEATURES = {
         "documentliteral",
@@ -431,7 +431,7 @@ public class WebProjectWebServicesSupport implements WebServicesSupportImpl {
         "donotoverride"
     };
     
-    private static final List importantSeiServiceFeatures = Arrays.asList(WSCOMPILE_KEY_SEI_SERVICE_FEATURES);
+    private static final List<String> importantSeiServiceFeatures = Arrays.asList(WSCOMPILE_KEY_SEI_SERVICE_FEATURES);
     
     private static final String [] WSCOMPILE_WSDL_SERVICE_FEATURES = {
         "datahandleronly", // WSDL - portable
@@ -456,7 +456,7 @@ public class WebProjectWebServicesSupport implements WebServicesSupportImpl {
         "donotunwrap", // WSDL - portable
     };
     
-    private static final List allWsdlServiceFeatures = Arrays.asList(WSCOMPILE_WSDL_SERVICE_FEATURES);
+    private static final List<String> allWsdlServiceFeatures = Arrays.asList(WSCOMPILE_WSDL_SERVICE_FEATURES);
     
     private static final String [] WSCOMPILE_KEY_WSDL_SERVICE_FEATURES = {
         "wsi",
@@ -471,7 +471,7 @@ public class WebProjectWebServicesSupport implements WebServicesSupportImpl {
         "explicitcontext",
     };
     
-    private static final List importantWsdlServiceFeatures = Arrays.asList(WSCOMPILE_KEY_WSDL_SERVICE_FEATURES);
+    private static final List<String> importantWsdlServiceFeatures = Arrays.asList(WSCOMPILE_KEY_WSDL_SERVICE_FEATURES);
     
     public List<WsCompileEditorSupport.ServiceSettings> getServices() {
         List<WsCompileEditorSupport.ServiceSettings> serviceList = new ArrayList<WsCompileEditorSupport.ServiceSettings>();
diff --git a/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/api/client/WsCompileClientEditorSupport.java b/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/api/client/WsCompileClientEditorSupport.java
index e094ac3a0e..fd4b9dfc2d 100644
--- a/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/api/client/WsCompileClientEditorSupport.java
+++ b/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/api/client/WsCompileClientEditorSupport.java
@@ -57,8 +57,8 @@ public interface WsCompileClientEditorSupport {
     public final class ServiceSettings {
         private String name;
         private ClientStubDescriptor stubType;
-        private List/*String*/ availableFeatures;
-        private List/*String*/ importantFeatures;
+        private List<String> availableFeatures;
+        private List<String> importantFeatures;
         private String currentFeatures;
         private String newFeatures;
         private boolean[] options;
@@ -96,11 +96,11 @@ public interface WsCompileClientEditorSupport {
             return newFeatures;
         }
         
-        public List/*String*/ getAvailableFeatures() {
+        public List<String> getAvailableFeatures() {
             return availableFeatures;
         }
         
-        public List/*String*/ getImportantFeatures() {
+        public List<String> getImportantFeatures() {
             return importantFeatures;
         }
         
diff --git a/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/spi/jaxws/client/JAXWSClientSupportImpl.java b/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/spi/jaxws/client/JAXWSClientSupportImpl.java
index 6ef2bc92ee..298fb73fe4 100644
--- a/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/spi/jaxws/client/JAXWSClientSupportImpl.java
+++ b/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/spi/jaxws/client/JAXWSClientSupportImpl.java
@@ -22,6 +22,7 @@ package org.netbeans.modules.websvc.spi.jaxws.client;
 import java.io.IOException;
 import java.net.URL;
 import java.util.List;
+import org.netbeans.modules.websvc.api.jaxws.project.config.Client;
 import org.netbeans.spi.project.support.ant.AntProjectHelper;
 
 import org.openide.filesystems.FileObject;
@@ -35,53 +36,53 @@ import org.openide.nodes.Node;
 /** SPI for JAXWSClientSupport
  */
 public interface JAXWSClientSupportImpl {
-    
+
     public static final String XML_RESOURCES_FOLDER="xml-resources"; //NOI18N
     public static final String CLIENTS_LOCAL_FOLDER="web-service-references"; //NOI18N
     public static final String CATALOG_FILE="catalog.xml"; //NOI18N
-    
-    
+
+
     /** Add JAX-WS Client to project.
      *  <ul>
      *  <li> add client element to jax-ws.xml (Netbeans specific configuration file)
-     *  <li> download the wsdl file(s) and all related XML artifacts to the project 
+     *  <li> download the wsdl file(s) and all related XML artifacts to the project
      *  <li> generate JAX-WS artifacts for web service specified by wsdlUrl.
      *  <li> this can be achieved by creating specific target in build-impl.xml, that calls wsimport task.
      *  </ul>
      * @param clientName proposed name for the client (the web service reference node display name)
      * @param wsdlURL URL for web service WSDL file
      * @param isJsr109 flag indicating the need to add JAX-WS libraries to project:
-     *        if (isJsr109==false) JAX-WS libraries should be added to the project classpath 
+     *        if (isJsr109==false) JAX-WS libraries should be added to the project classpath
      * @return unique name for WS Client in the project(can be different than requested clientName)
      */
     public String addServiceClient(String clientName, String wsdlUrl, String packageName, boolean isJsr109);
-    
+
     /** Get WSDL folder for the project (folder containing wsdl files)
      *  The folder is used to save remote or local wsdl files to be available within the jar/war files.
      *  it is usually META-INF/wsdl folder (or WEB-INF/wsdl for web application)
      *  @param createFolder if (createFolder==true) the folder will be created (if not created before)
-     *  @return the file object (folder) where wsdl files are located in project 
+     *  @return the file object (folder) where wsdl files are located in project
      */
     public FileObject getWsdlFolder(boolean createFolder) throws IOException;
-    
+
     /** Get folder for local WSDL and XML artifacts for given client
      * This is the location where wsdl/xml files are downloaded to the project.
      * JAX-WS java artifacts will be generated from these local files instead of remote.
      * @param clientName client name (the web service reference node display name)
      * @param createFolder if (createFolder==true) the folder will be created (if not created before)
-     * @return the file object (folder) where wsdl files are located in project 
+     * @return the file object (folder) where wsdl files are located in project
      */
     public FileObject getLocalWsdlFolderForClient(String clientName, boolean createFolder);
-    
+
     /** Get folder for local jaxb binding (xml) files for given client
      *  This is the location where external jaxb binding files are downloaded to the project.
      *  JAX-WS java artifacts will be generated using these local binding files instead of remote.
      * @param clientName client name (the web service reference node display name)
      * @param createFolder if (createFolder==true) the folder will be created (if not created before)
-     * @return the file object (folder) where jaxb binding files are located in project 
+     * @return the file object (folder) where jaxb binding files are located in project
      */
     public FileObject getBindingsFolderForClient(String clientName, boolean createFolder);
-    
+
     /** Remove JAX-WS Client from project.
      * <ul>
      *  <li> remove client element from jax-ws.xml (Netbeans specific configuration file)
@@ -91,23 +92,24 @@ public interface JAXWSClientSupportImpl {
      * @param clientName client name (the web service reference node display name)
      */
     public void removeServiceClient(String serviceName);
-    
+
     /** Get list of all JAX-WS Clients in project
      * @param clientName client name (the web service reference node display name)
+     * @return a list of Clients
      */
-    public List getServiceClients();
-    
+    public List<Client> getServiceClients();
+
     /** gets the URL of catalog.xml file
      *  (the catalog is used by wsimport to locate local wsdl/xml resources)
      * @return URL url of the car
      */
     public URL getCatalog();
-    
+
     /** intended to be used to obtain service-ref name for given web service reference
      *  (currently not used in projects)
      */
     public String getServiceRefName(Node clientNode);
-    
+
     /**
      * Get the AntProjectHelper from the project
      */
diff --git a/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/spi/jaxws/client/ProjectJAXWSClientSupport.java b/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/spi/jaxws/client/ProjectJAXWSClientSupport.java
index f3edb2ec14..69cf08de1a 100644
--- a/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/spi/jaxws/client/ProjectJAXWSClientSupport.java
+++ b/enterprise/websvc.clientapi/src/org/netbeans/modules/websvc/spi/jaxws/client/ProjectJAXWSClientSupport.java
@@ -347,8 +347,8 @@ public abstract class ProjectJAXWSClientSupport implements JAXWSClientSupportImp
         }
     }
 
-    public List getServiceClients() {
-        List<Client> jaxWsClients = new ArrayList<Client>();
+    public List<Client> getServiceClients() {
+        List<Client> jaxWsClients = new ArrayList<>();
         JaxWsModel jaxWsModel = project.getLookup().lookup(JaxWsModel.class);
         if (jaxWsModel!=null) {
             Client[] clients = jaxWsModel.getClients();
diff --git a/enterprise/websvc.manager/src/org/netbeans/modules/websvc/manager/model/WebServiceListModel.java b/enterprise/websvc.manager/src/org/netbeans/modules/websvc/manager/model/WebServiceListModel.java
index f70b7bede3..cdbd37780f 100644
--- a/enterprise/websvc.manager/src/org/netbeans/modules/websvc/manager/model/WebServiceListModel.java
+++ b/enterprise/websvc.manager/src/org/netbeans/modules/websvc/manager/model/WebServiceListModel.java
@@ -95,7 +95,7 @@ public class WebServiceListModel {
         return partnerServices;
     }
 
-    private static boolean containsKey(List list, String key) {
+    private static boolean containsKey(List<?> list, String key) {
         synchronized (list) {
             for (Object o : list) {
                 if (o instanceof WebServiceData) {
diff --git a/enterprise/websvc.websvcapi/src/org/netbeans/modules/websvc/api/webservices/WebServicesSupport.java b/enterprise/websvc.websvcapi/src/org/netbeans/modules/websvc/api/webservices/WebServicesSupport.java
index 0acee0dc07..978cf7ec9e 100644
--- a/enterprise/websvc.websvcapi/src/org/netbeans/modules/websvc/api/webservices/WebServicesSupport.java
+++ b/enterprise/websvc.websvcapi/src/org/netbeans/modules/websvc/api/webservices/WebServicesSupport.java
@@ -138,7 +138,7 @@ public final class WebServicesSupport {
         return impl.getReferenceHelper();
     }
     
-    public List/*WsCompileEditorSupport.ServiceSettings*/ getServices() {
+    public List<WsCompileEditorSupport.ServiceSettings> getServices() {
         return impl.getServices();
     }
     
diff --git a/enterprise/websvc.websvcapi/src/org/netbeans/modules/websvc/spi/webservices/WebServicesSupportImpl.java b/enterprise/websvc.websvcapi/src/org/netbeans/modules/websvc/spi/webservices/WebServicesSupportImpl.java
index edb1c2c2b1..173a39a30f 100644
--- a/enterprise/websvc.websvcapi/src/org/netbeans/modules/websvc/spi/webservices/WebServicesSupportImpl.java
+++ b/enterprise/websvc.websvcapi/src/org/netbeans/modules/websvc/spi/webservices/WebServicesSupportImpl.java
@@ -26,6 +26,7 @@ import org.openide.filesystems.FileObject;
 import org.netbeans.spi.project.support.ant.AntProjectHelper;
 import org.netbeans.api.project.Project;
 import org.netbeans.modules.j2ee.dd.api.webservices.ServiceImplBean;
+import org.netbeans.modules.websvc.api.webservices.WsCompileEditorSupport;
 import org.netbeans.spi.project.support.ant.ReferenceHelper;
 
 /**
@@ -106,7 +107,7 @@ public interface WebServicesSupportImpl {
     /**
      * Get the list of services and their wscompile settings.
      */
-    public List/*WsCompileEditorSupport.ServiceSettings*/ getServices();
+    public List<WsCompileEditorSupport.ServiceSettings> getServices();
     
     /**
      * Add infrastructure methods and fields (if any) that should be present
diff --git a/groovy/groovy.editor/src/org/netbeans/modules/groovy/editor/actions/FixImportsAction.java b/groovy/groovy.editor/src/org/netbeans/modules/groovy/editor/actions/FixImportsAction.java
index abb57adaa5..ce48c9a2ff 100644
--- a/groovy/groovy.editor/src/org/netbeans/modules/groovy/editor/actions/FixImportsAction.java
+++ b/groovy/groovy.editor/src/org/netbeans/modules/groovy/editor/actions/FixImportsAction.java
@@ -24,6 +24,7 @@ import java.util.*;
 import javax.swing.text.JTextComponent;
 import org.codehaus.groovy.ast.ModuleNode;
 import org.codehaus.groovy.control.ErrorCollector;
+import org.codehaus.groovy.control.messages.Message;
 import org.codehaus.groovy.control.messages.SyntaxErrorMessage;
 import org.codehaus.groovy.syntax.SyntaxException;
 import org.netbeans.api.editor.EditorActionRegistration;
@@ -103,7 +104,7 @@ public class FixImportsAction extends BaseAction {
                 if (errorCollector == null) {
                     return;
                 }
-                List errors = errorCollector.getErrors();
+                List<? extends Message> errors = errorCollector.getErrors();
                 if (errors == null) {
                     return;
                 }
@@ -112,8 +113,8 @@ public class FixImportsAction extends BaseAction {
             }
         }
 
-        private void collectMissingImports(List errors) {
-            for (Object error : errors) {
+        private void collectMissingImports(List<? extends Message> errors) {
+            for (Message error : errors) {
                 if (error instanceof SyntaxErrorMessage) {
                     SyntaxException se = ((SyntaxErrorMessage) error).getCause();
 
diff --git a/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilder.java b/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilder.java
index 7ac0f0603c..6ccfbce74d 100644
--- a/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilder.java
+++ b/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilder.java
@@ -758,7 +758,7 @@ public class QueryBuilder extends TopComponent
         
         // we could reuse this to find the tablename if the user
         // only specifies "select 'column_name' from 'table_name'"
-        List fromTables;
+        List<JoinTable> fromTables;
         // from
         if ( _queryModel.getFrom() != null ) {
 
@@ -904,7 +904,7 @@ public class QueryBuilder extends TopComponent
             {
                 // Check every table in the From list, to see if any have
                 // this column
-                List fromTables = _queryModel.getFrom().getTableList();
+                List<JoinTable> fromTables = _queryModel.getFrom().getTableList();
                 boolean found=false;
                 for ( int j = 0; j < fromTables.size(); j++ ) {
                     String fromTableName = ( (JoinTable) fromTables.get(j) ).getFullTableName();
diff --git a/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilderGraphFrame.java b/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilderGraphFrame.java
index 3a93ac7acc..03064c8f64 100644
--- a/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilderGraphFrame.java
+++ b/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilderGraphFrame.java
@@ -848,7 +848,7 @@ public class QueryBuilderGraphFrame extends JPanel
                 SQLQueryFactory.createTable(tableName, corrName, schemaName);
             JoinTable joinTable=SQLQueryFactory.createJoinTable(tbl);
             
-            List columnNames = new ArrayList();
+            List<String> columnNames = new ArrayList<>();
             columnNames.add("*"); // NOI18N
             
             // Insert the table into the model first, so that column insertions can refer to it
diff --git a/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilderMetaData.java b/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilderMetaData.java
index 56cdd7f3cc..0092d39fb1 100644
--- a/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilderMetaData.java
+++ b/ide/db.sql.visualeditor/src/org/netbeans/modules/db/sql/visualeditor/querybuilder/QueryBuilderMetaData.java
@@ -260,7 +260,7 @@ public class QueryBuilderMetaData {
         boolean retVal = false;
 
         // TODO JFB should not catch this.
-        List cols;
+        List<String> cols;
         String checkedTable;
         try {
             checkedTable = checkTableName(tableName);
@@ -433,8 +433,8 @@ public class QueryBuilderMetaData {
         List<List<String>> tables = getTables();
 
         // Convert from List<table, schema> to "table.schema", expected by query editor
-        List<String> result = new ArrayList<String>();
-        for (List fullTable : tables) {
+        List<String> result = new ArrayList<>();
+        for (List<String> fullTable : tables) {
             String schema = (String) fullTable.get(0);
             String table = (String) fullTable.get(1);
             result.add(((schema == null) || (schema.equals(""))) ? table : schema + "." + table);
@@ -797,7 +797,7 @@ public class QueryBuilderMetaData {
 
 
     // Get the list of column names associated with the specified table name, with no Exception
-    public void getColumnNames(String fullTableName, List columnNames) {
+    public void getColumnNames(String fullTableName, List<String> columnNames) {
         try {
             columnNames.addAll(getColumnNames(fullTableName));
         } catch (SQLException sqle) {
@@ -846,7 +846,7 @@ public class QueryBuilderMetaData {
     /**
      * Returns the primary key columns of the specified table
      */
-    List getPrimaryKeys(String fullTableName) throws SQLException {
+    List<String> getPrimaryKeys(String fullTableName) throws SQLException {
 
         Log.getLogger().entering("QueryBuilderMetaData", "getPrimaryKeys", fullTableName); // NOI18N
         String schemaName = null;
@@ -859,42 +859,6 @@ public class QueryBuilderMetaData {
             tableName = table[0];
         }
         return getPrimaryKeys(schemaName, tableName);
-
-        /*
-        List primaryKeys = new ArrayList();
-        String tableName, schemaName=null;
-        String[] table = fullTableName.split("\\."); // NOI18N
-        if (table.length>1) {
-	    schemaName=table[0];
-	    tableName = table[1];
-        } else
-	    tableName=table[0];
-        boolean firstTime = true;
-        while ( true ) {
-	    try {
-		checkMetaData();
-		ResultSet rs = _databaseMetaData.getPrimaryKeys(null, schemaName, tableName);
-		if (rs != null) {
-		    String name;
-		    while (rs.next()) {
-			name = rs.getString("COLUMN_NAME"); // NOI18N
-			primaryKeys.add(name);
-		    }
-		    rs.close();
-		}
-		break;
-	    } catch (SQLException sqle) {
-		if ( firstTime ) {
-		    refreshDataBaseMetaData();
-		    firstTime = false;
-		} else {
-		    reportDatabaseError("DATABASE_ERROR", sqle); // NOI18N
-		    break;
-		}
-	    }
-        }
-        return primaryKeys;
-        **/
     }
 
     //    private List<List<String>> allTables = null ;
diff --git a/ide/xml.core/src/org/netbeans/modules/xml/api/model/ExtendedGrammarQuery.java b/ide/xml.core/src/org/netbeans/modules/xml/api/model/ExtendedGrammarQuery.java
index 2025f59cf3..9cdd3db048 100644
--- a/ide/xml.core/src/org/netbeans/modules/xml/api/model/ExtendedGrammarQuery.java
+++ b/ide/xml.core/src/org/netbeans/modules/xml/api/model/ExtendedGrammarQuery.java
@@ -32,6 +32,6 @@ import java.util.List;
 public interface ExtendedGrammarQuery extends GrammarQuery {
     
     /** @return a List of resolved entities System id-s names.*/
-    public List/*<String>*/ getResolvedEntities();
+    public List<String> getResolvedEntities();
     
 }
diff --git a/ide/xml.core/src/org/netbeans/modules/xml/dtd/grammar/DTDGrammar.java b/ide/xml.core/src/org/netbeans/modules/xml/dtd/grammar/DTDGrammar.java
index bfa237291b..d3abe20806 100644
--- a/ide/xml.core/src/org/netbeans/modules/xml/dtd/grammar/DTDGrammar.java
+++ b/ide/xml.core/src/org/netbeans/modules/xml/dtd/grammar/DTDGrammar.java
@@ -24,8 +24,6 @@ import javax.swing.Icon;
 
 import org.w3c.dom.*;
 
-import org.openide.ErrorManager;
-
 import org.netbeans.modules.xml.api.model.*;
 import org.netbeans.modules.xml.spi.dom.*;
 
@@ -70,11 +68,11 @@ class DTDGrammar implements ExtendedGrammarQuery {
         this.emptyElements = emptyElements;
     }
 
-    void setResolvedEntities(List/*<String>*/ resolvedEntities) {
+    void setResolvedEntities(List<String> resolvedEntities) {
         this.resolvedEntities = resolvedEntities;
     }
     
-    public List/*<String>*/ getResolvedEntities() {
+    public List<String> getResolvedEntities() {
         return resolvedEntities;
     }
     
diff --git a/ide/xml.text.obsolete90/src/org/netbeans/modules/xml/text/obsolete90/ComplexValueSettingsFactory.java b/ide/xml.text.obsolete90/src/org/netbeans/modules/xml/text/obsolete90/ComplexValueSettingsFactory.java
deleted file mode 100644
index c93633b88e..0000000000
--- a/ide/xml.text.obsolete90/src/org/netbeans/modules/xml/text/obsolete90/ComplexValueSettingsFactory.java
+++ /dev/null
@@ -1,38 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-package org.netbeans.modules.xml.text.obsolete90;
-
-import java.util.Collections;
-import java.util.List;
-import org.netbeans.modules.xml.text.api.XMLDefaultTokenContext;
-import org.netbeans.modules.xml.text.syntax.DTDTokenContext;
-
-/**
- *
- * @author sdedic
- */
-public class ComplexValueSettingsFactory {
-    public static List getXMLTokenContext() {
-        return Collections.singletonList(XMLDefaultTokenContext.context);
-    }
-    // XXX: use lexer
-    public static List getDTDTokenContext() {
-        return Collections.singletonList(DTDTokenContext.context);
-    }
-}
diff --git a/ide/xml.text/src/org/netbeans/modules/xml/text/completion/GrammarManager.java b/ide/xml.text/src/org/netbeans/modules/xml/text/completion/GrammarManager.java
index c91148d5b4..90f99457f7 100644
--- a/ide/xml.text/src/org/netbeans/modules/xml/text/completion/GrammarManager.java
+++ b/ide/xml.text/src/org/netbeans/modules/xml/text/completion/GrammarManager.java
@@ -62,7 +62,7 @@ class GrammarManager extends FileChangeAdapter implements DocumentListener {
 
     private static final String FILE_PROTOCOL_URI_PREFIX = "file:/"; //NOI18N
     
-    private ArrayList<FileObject> externalDTDs = new ArrayList();
+    private List<FileObject> externalDTDs = new ArrayList<>();
     
     // current cache state
     private int state = INVALID;
@@ -291,7 +291,7 @@ class GrammarManager extends FileChangeAdapter implements DocumentListener {
                 
                 if(loaded instanceof ExtendedGrammarQuery) {
                     //attach listeners to external files and if any of them changes then reload this grammar
-                    for(String resolvedEntity : (List<String>)((ExtendedGrammarQuery)loaded).getResolvedEntities()) {
+                    for (String resolvedEntity : ((ExtendedGrammarQuery)loaded).getResolvedEntities()) {
                         //filter non-files resolved entities
                         if(!resolvedEntity.startsWith(FILE_PROTOCOL_URI_PREFIX)) continue;
                         
diff --git a/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/editor/completion/ETCompletionContextResolver.java b/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/editor/completion/ETCompletionContextResolver.java
index d1f35e2352..c463fcd066 100644
--- a/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/editor/completion/ETCompletionContextResolver.java
+++ b/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/editor/completion/ETCompletionContextResolver.java
@@ -53,7 +53,7 @@ public class ETCompletionContextResolver implements CompletionContextResolver {
     private static final Logger LOGGER = Logger.getLogger(ETCompletionContextResolver.class.getName());
     
     @Override
-    public List resolve(JPACodeCompletionProvider.Context ctx) {
+    public List<JPACompletionItem> resolve(JPACodeCompletionProvider.Context ctx) {
         
         List<JPACompletionItem> result = new ResultItemsFilterList(ctx);
         
@@ -125,7 +125,7 @@ public class ETCompletionContextResolver implements CompletionContextResolver {
         return results;
     }
     
-     private List completeJPQLContext(JPACodeCompletionProvider.Context ctx, CCParser.CC nn, CCParser.NNAttr nnattr, List<JPACompletionItem> results) {
+     private List<JPACompletionItem> completeJPQLContext(JPACodeCompletionProvider.Context ctx, CCParser.CC nn, CCParser.NNAttr nnattr, List<JPACompletionItem> results) {
         String completedMember = nnattr.getName();
 
         if (completedMember == null || "query".equals(completedMember)) { // NOI18N
@@ -161,7 +161,8 @@ public class ETCompletionContextResolver implements CompletionContextResolver {
         
         return results;
     }
-     private List completeJPQLContext(JPACodeCompletionProvider.Context ctx, CCParser.MD method, List<JPACompletionItem> results) {
+
+     private List<JPACompletionItem> completeJPQLContext(JPACodeCompletionProvider.Context ctx, CCParser.MD method, List<JPACompletionItem> results) {
 
             String completedValue = method.getValue();
             if(completedValue == null) {
diff --git a/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/entitygenerator/CMPMappingModel.java b/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/entitygenerator/CMPMappingModel.java
index e168c86e3e..51bba1564d 100644
--- a/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/entitygenerator/CMPMappingModel.java
+++ b/java/j2ee.persistence/src/org/netbeans/modules/j2ee/persistence/entitygenerator/CMPMappingModel.java
@@ -182,7 +182,7 @@ public class CMPMappingModel {
         while (keyIt.hasNext()) {
             String key = keyIt.next();
             ColumnData[] value = cmrFieldMapping.get(key);
-            List l = Arrays.asList(value);
+            List<ColumnData> l = Arrays.asList(value);
             Object otherValue = other.cmrFieldMapping.get(key);
             if (otherValue == null || 
                 !l.equals(Arrays.asList(other.cmrFieldMapping.get(key)))) {
diff --git a/java/java.freeform/src/org/netbeans/modules/java/freeform/JavaProjectGenerator.java b/java/java.freeform/src/org/netbeans/modules/java/freeform/JavaProjectGenerator.java
index 51ea47563f..51df24e39a 100644
--- a/java/java.freeform/src/org/netbeans/modules/java/freeform/JavaProjectGenerator.java
+++ b/java/java.freeform/src/org/netbeans/modules/java/freeform/JavaProjectGenerator.java
@@ -229,7 +229,7 @@ public class JavaProjectGenerator {
      *    all styles will be read. Useful for reading one style of source folders.
      * @return list of SourceFolder instances; type value will be always null
      */
-    public static List getSourceViews(AntProjectHelper helper, String style) {
+    public static List<SourceFolder> getSourceViews(AntProjectHelper helper, String style) {
         //assert ProjectManager.mutex().isReadAccess() || ProjectManager.mutex().isWriteAccess();
         List<SourceFolder> list = new ArrayList<SourceFolder>();
         Element data = Util.getPrimaryConfigurationData(helper);
diff --git a/java/maven.grammar/src/org/netbeans/modules/maven/grammar/effpom/AnnotationMarkProvider.java b/java/maven.grammar/src/org/netbeans/modules/maven/grammar/effpom/AnnotationMarkProvider.java
index ddcc516047..f680427f31 100644
--- a/java/maven.grammar/src/org/netbeans/modules/maven/grammar/effpom/AnnotationMarkProvider.java
+++ b/java/maven.grammar/src/org/netbeans/modules/maven/grammar/effpom/AnnotationMarkProvider.java
@@ -32,7 +32,7 @@ import org.netbeans.modules.editor.errorstripe.privatespi.MarkProvider;
     private List<AnnotationMark> marks = Collections.emptyList();
 
     public void setMarks (List<AnnotationMark> marks) {
-        List old = this.marks;
+        List<AnnotationMark> old = this.marks;
         this.marks = marks;
         firePropertyChange(PROP_MARKS, old, marks);
     }
diff --git a/platform/openide.util/src/org/netbeans/modules/openide/util/DefaultMutexImplementation.java b/platform/openide.util/src/org/netbeans/modules/openide/util/DefaultMutexImplementation.java
index 4330cc329c..20cb27f3d3 100644
--- a/platform/openide.util/src/org/netbeans/modules/openide/util/DefaultMutexImplementation.java
+++ b/platform/openide.util/src/org/netbeans/modules/openide/util/DefaultMutexImplementation.java
@@ -1091,17 +1091,16 @@ public class DefaultMutexImplementation implements MutexImplementation {
         /** Adds the Runnable into the queue of waiting requests */
         public void enqueue(int mode, Runnable run) {
             if (queues[mode] == null) {
-                queues[mode] = new ArrayList<Runnable>(13);
+                queues[mode] = new ArrayList<>(13);
             }
 
             queues[mode].add(run);
         }
 
         /** @return a List of enqueued Runnables - may be null */
-        public List dequeue(int mode) {
+        public List<Runnable> dequeue(int mode) {
             List<Runnable> ret = queues[mode];
             queues[mode] = null;
-
             return ret;
         }
 
diff --git a/platform/openide.util/src/org/openide/util/TopologicalSortException.java b/platform/openide.util/src/org/openide/util/TopologicalSortException.java
index 537c31245b..7f64f30cc2 100644
--- a/platform/openide.util/src/org/openide/util/TopologicalSortException.java
+++ b/platform/openide.util/src/org/openide/util/TopologicalSortException.java
@@ -60,7 +60,7 @@ public final class TopologicalSortException extends Exception {
     public final List partialSort() {
         Set[] all = topologicalSets();
 
-        ArrayList<Object> res = new ArrayList<Object>(vertexes.size());
+        List<Object> res = new ArrayList<Object>(vertexes.size());
 
         for (int i = 0; i < all.length; i++) {
             for (Object e : all[i]) {
diff --git a/profiler/lib.profiler.ui/src/org/netbeans/lib/profiler/ui/components/JTreeTable.java b/profiler/lib.profiler.ui/src/org/netbeans/lib/profiler/ui/components/JTreeTable.java
index 752b6b96f6..c6ed31cb3f 100644
--- a/profiler/lib.profiler.ui/src/org/netbeans/lib/profiler/ui/components/JTreeTable.java
+++ b/profiler/lib.profiler.ui/src/org/netbeans/lib/profiler/ui/components/JTreeTable.java
@@ -908,11 +908,11 @@ public class JTreeTable extends JTable implements CellTipAware, MouseListener, M
         treeTableModelAdapter.changeRoot(newRoot);
     }
     
-    public void setup(List expanded, TreePath selected) {
+    public void setup(List<TreePath> expanded, TreePath selected) {
         treeTableModelAdapter.setup(expanded, selected);
     }
     
-    public List getExpandedPaths() {
+    public List<TreePath> getExpandedPaths() {
         return treeTableModelAdapter.getExpandedPaths();
     }
 
diff --git a/profiler/lib.profiler.ui/src/org/netbeans/lib/profiler/ui/components/treetable/TreeTableModelAdapter.java b/profiler/lib.profiler.ui/src/org/netbeans/lib/profiler/ui/components/treetable/TreeTableModelAdapter.java
index 75e49a4eea..bd63431318 100644
--- a/profiler/lib.profiler.ui/src/org/netbeans/lib/profiler/ui/components/treetable/TreeTableModelAdapter.java
+++ b/profiler/lib.profiler.ui/src/org/netbeans/lib/profiler/ui/components/treetable/TreeTableModelAdapter.java
@@ -130,9 +130,9 @@ public class TreeTableModelAdapter extends AbstractTableModel {
      * re-open the paths in a tree after a call to 'treeStructureChanged'
      * (which causes all open paths to collapse)
      */
-    public List getExpandedPaths() {
-        Enumeration expanded = tree.getExpandedDescendants(getRootPath());
-        List paths = new ArrayList();
+    public List<TreePath> getExpandedPaths() {
+        Enumeration<TreePath> expanded = tree.getExpandedDescendants(getRootPath());
+        List<TreePath> paths = new ArrayList<>();
 
         if (expanded != null) {
             while (expanded.hasMoreElements()) {
@@ -188,9 +188,9 @@ public class TreeTableModelAdapter extends AbstractTableModel {
      *
      * @param paths a List of TreePaths which are going to be opened.
      */
-    public void restoreExpandedPaths(List paths) {
+    public void restoreExpandedPaths(List<TreePath> paths) {
         tree.putClientProperty(UIUtils.PROP_EXPANSION_TRANSACTION, Boolean.TRUE); // NOI18N
-        for (Object p : paths) {
+        for (TreePath p : paths) {
             tree.expandPath((TreePath)p);
         }
         tree.putClientProperty(UIUtils.PROP_EXPANSION_TRANSACTION, Boolean.FALSE); // NOI18N
@@ -280,7 +280,7 @@ public class TreeTableModelAdapter extends AbstractTableModel {
         });
     }
     
-    public void setup(List expanded, final TreePath selected) {
+    public void setup(List<TreePath> expanded, final TreePath selected) {
         tree.getSelectionModel().clearSelection();
         treeTableModel.fireTreeStructureChanged(this,
                                                 treeTableModel.getPathToRoot((CCTNode) treeTableModel.getRoot()),
diff --git a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ClassesController.java b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ClassesController.java
index a4eb87e49c..8c987406a6 100644
--- a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ClassesController.java
+++ b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ClassesController.java
@@ -39,12 +39,12 @@ public class ClassesController extends AbstractTopLevelController implements Fie
         //~ Instance fields ------------------------------------------------------------------------------------------------------
 
         private final long javaClassID;
-        private final List expandedStaticFields;
+        private final List<TreePath> expandedStaticFields;
         private final TreePath selectedStaticField;
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public Configuration(long javaClassID, List expandedStaticFields, TreePath selectedStaticField) {
+        public Configuration(long javaClassID, List<TreePath> expandedStaticFields, TreePath selectedStaticField) {
             this.javaClassID = javaClassID;
             this.expandedStaticFields = expandedStaticFields;
             this.selectedStaticField = selectedStaticField;
@@ -56,7 +56,7 @@ public class ClassesController extends AbstractTopLevelController implements Fie
             return javaClassID;
         }
         
-        public List getExpandedStaticFields() {
+        public List<TreePath> getExpandedStaticFields() {
             return expandedStaticFields;
         }
         
@@ -92,7 +92,7 @@ public class ClassesController extends AbstractTopLevelController implements Fie
     public Configuration getCurrentConfiguration() {
         // Selected class
         long selectedClassID = -1;
-        List expandedStaticFields = null;
+        List<TreePath> expandedStaticFields = null;
         TreePath selectedStaticField = null;
         JavaClass selectedClass = getSelectedClass();
 
diff --git a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/FieldsBrowserController.java b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/FieldsBrowserController.java
index 272d490c1c..b4a15f065d 100644
--- a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/FieldsBrowserController.java
+++ b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/FieldsBrowserController.java
@@ -252,7 +252,7 @@ public class FieldsBrowserController extends AbstractController {
         return ((FieldsBrowserControllerUI) getPanel()).getPresenter();
     }
 
-    public List getExpandedPaths() {
+    public List<TreePath> getExpandedPaths() {
         return ((FieldsBrowserControllerUI)getPanel()).getExpandedPaths();
     }
 
diff --git a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/InstancesController.java b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/InstancesController.java
index 1f8f886de0..5b3748e745 100644
--- a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/InstancesController.java
+++ b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/InstancesController.java
@@ -40,15 +40,15 @@ public class InstancesController extends AbstractTopLevelController implements F
         //~ Instance fields ------------------------------------------------------------------------------------------------------
 
         private final long instanceID;
-        private final List expandedFields;
+        private final List<TreePath> expandedFields;
         private final TreePath selectedField;
-        private final List expandedReferences;
+        private final List<TreePath> expandedReferences;
         private final TreePath selectedReference;
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public Configuration(long instanceID, List expandedFields, TreePath selectedField,
-                             List expandedReferences, TreePath selectedReference) {
+        public Configuration(long instanceID, List<TreePath> expandedFields, TreePath selectedField,
+                             List<TreePath> expandedReferences, TreePath selectedReference) {
             this.instanceID = instanceID;
             this.expandedFields = expandedFields;
             this.selectedField = selectedField;
@@ -62,7 +62,7 @@ public class InstancesController extends AbstractTopLevelController implements F
             return instanceID;
         }
         
-        public List getExpandedFields() {
+        public List<TreePath> getExpandedFields() {
             return expandedFields;
         }
         
@@ -143,9 +143,9 @@ public class InstancesController extends AbstractTopLevelController implements F
     public Configuration getCurrentConfiguration() {
         // Selected instance
         long selectedInstanceID = -1;
-        List expandedFields = null;
+        List<TreePath> expandedFields = null;
         TreePath selectedField = null;
-        List expandedReferences = null;
+        List<TreePath> expandedReferences = null;
         TreePath selectedReference = null;
         Instance selectedInstance = getSelectedInstance();
 
diff --git a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ReferencesBrowserController.java b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ReferencesBrowserController.java
index 54cc17079e..90100dce86 100644
--- a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ReferencesBrowserController.java
+++ b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ReferencesBrowserController.java
@@ -279,7 +279,7 @@ public class ReferencesBrowserController extends AbstractController {
         return ((ReferencesBrowserControllerUI) getPanel()).getPresenter();
     }
     
-    public List getExpandedPaths() {
+    public List<TreePath> getExpandedPaths() {
         return ((ReferencesBrowserControllerUI)getPanel()).getExpandedPaths();
     }
     
diff --git a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/model/BrowserUtils.java b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/model/BrowserUtils.java
index 6bdf51980c..cc6dfd7640 100644
--- a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/model/BrowserUtils.java
+++ b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/model/BrowserUtils.java
@@ -194,11 +194,11 @@ public class BrowserUtils {
         return new TreePath(p.toArray());
     }
     
-    public static void restoreState(final JTreeTable ttable, List paths, TreePath selected) {
+    public static void restoreState(final JTreeTable ttable, List<TreePath> paths, TreePath selected) {
         if (paths != null) {
             JTree tree = ttable.getTree();
             HeapWalkerNode root = (HeapWalkerNode)tree.getModel().getRoot();
-            for (Object path : paths) ensurePathComputed(root, (TreePath)path, new HashSet());
+            for (TreePath path : paths) ensurePathComputed(root, (TreePath)path, new HashSet());
             ttable.setup(paths, selected);
         }
     }
diff --git a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ui/FieldsBrowserControllerUI.java b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ui/FieldsBrowserControllerUI.java
index 3c90101057..ecd1f11ece 100644
--- a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ui/FieldsBrowserControllerUI.java
+++ b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ui/FieldsBrowserControllerUI.java
@@ -337,10 +337,10 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
         fieldsListTable.selectNode(node, true);
     }
     
-    private List expandedPaths = null;
+    private List<TreePath> expandedPaths = null;
     private TreePath selectedPath = null;
     
-    public List getExpandedPaths() {
+    public List<TreePath> getExpandedPaths() {
         if (!showsData()) return null;
         return fieldsListTable.getExpandedPaths();
     }
@@ -350,7 +350,7 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
         return fieldsListTable.getTree().getSelectionPath();
     }
     
-    public void restoreState(List expanded, TreePath selected) {
+    public void restoreState(List<TreePath> expanded, TreePath selected) {
         if (showsData()) {
             expandedPaths = expanded;
             selectedPath = selected;
diff --git a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ui/ReferencesBrowserControllerUI.java b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ui/ReferencesBrowserControllerUI.java
index d54b28ae5c..19931f3f9e 100644
--- a/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ui/ReferencesBrowserControllerUI.java
+++ b/profiler/profiler.heapwalker/src/org/netbeans/modules/profiler/heapwalk/ui/ReferencesBrowserControllerUI.java
@@ -368,7 +368,7 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
     private List expandedPaths = null;
     private TreePath selectedPath = null;
     
-    public List getExpandedPaths() {
+    public List<TreePath> getExpandedPaths() {
         if (!showsData()) return null;
         return fieldsListTable.getExpandedPaths();
     }


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@netbeans.apache.org
For additional commands, e-mail: commits-help@netbeans.apache.org

For further information about the NetBeans mailing lists, visit:
https://cwiki.apache.org/confluence/display/NETBEANS/Mailing+lists
diff --git a/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/common/xmlutils/XMLJ2eeUtils.java b/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/common/xmlutils/XMLJ2eeUtils.java
index 56544f482d..e3abd42fc9 100644
--- a/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/common/xmlutils/XMLJ2eeUtils.java
+++ b/enterprise/j2ee.ddloaders/src/org/netbeans/modules/j2ee/ddloaders/common/xmlutils/XMLJ2eeUtils.java
@@ -144,6 +144,7 @@ public class XMLJ2eeUtils {
             }
         }        
     }
+
     /** This method update document in editor after change in beans hierarchy.
      * It takes old document and new document in String.
      * To avoid regeneration of whole document in text editor following steps are done:
@@ -289,14 +290,15 @@ public class XMLJ2eeUtils {
         }
         return new String(text, 0, pos - 1);
     }
+
     /** This method updates the attribute specified by the elementPath in DOM tree
      * @param root Root element of the DOM graph 
      * @param elementPath List defining the element path to the target element 
      * @param attrName Attribute name of the target attribute 
      * @param attrValue New value for the attribute defined by attrName
-     * @return true if method was succesful, false otherwise
+     * @return true if method was successful, false otherwise
      */    
-    public static boolean changeAttribute (Element root, List elementPath, String attrName, String attrValue)
+    public static boolean changeAttribute (Element root, List<ElementAttrInfo> elementPath, String attrName, String attrValue)
     throws org.w3c.dom.DOMException {
        
         //if (elementPath.size()==0) return false;
@@ -351,9 +353,9 @@ public class XMLJ2eeUtils {
         }
         return true;
     }
-    public static boolean changeAttribute (Element root, List elementPath, String elementName, int index, String attrName, String attrValue)
+    public static boolean changeAttribute (Element root, List<ElementAttrInfo> elementPath, String elementName, int index, String attrName, String attrValue)
     throws org.w3c.dom.DOMException {
-        if (elementPath.size()==0) return false;
+        if (elementPath.isEmpty()) return false;
         Iterator<ElementAttrInfo> it = elementPath.iterator();
         Element element = root;
         //String keyAttributeName=null;
@@ -393,15 +395,16 @@ public class XMLJ2eeUtils {
             element.setAttribute(attrName,attrValue);
         }
         return true;
-    }    
+    }
+
     /** This method deletes the element specified by elementPath from the DOM tree
      * @param root Root element of the DOM graph 
      * @param elementPath List defining the element path to the target element 
      * @return true if method was succesful, false otherwise
      */    
-    public static boolean deleteElement (Element root, List elementPath)
+    public static boolean deleteElement (Element root, List<ElementAttrInfo> elementPath)
     throws org.w3c.dom.DOMException {
-        if (elementPath.size()==0) return false;
+        if (elementPath.isEmpty()) return false;
         Iterator<ElementAttrInfo> it = elementPath.iterator();
         Element parent = null;
         Element element = root;
@@ -449,17 +452,18 @@ public class XMLJ2eeUtils {
         
         return true;
     }
+
     /** This method adds the element specified by elementName and element attributes into the element
      * specified by the elementPath
      * @param root Root element of the DOM graph 
      * @param elementPath List defining the element path to the target element
      * @param elementName name of the new Element
      * @param keyAttribute key Attribute of the new Element
      * @param attrNames names of the attributes that will be initialized
      * @param attrValues initial values for attrNames
-     * @return true if method was succesful, false otherwise
+     * @return true if method was successful, false otherwise
      */ 
-    public static boolean addElement (Element root, List elementPath, String elementName, String keyAttribute, String[] attrNames, String[] attrValues){
+    public static boolean addElement (Element root, List<ElementAttrInfo> elementPath, String elementName, String keyAttribute, String[] attrNames, String[] attrValues){
         Iterator<ElementAttrInfo> it = elementPath.iterator();
         Element element = root;
         while (it.hasNext()){
@@ -547,12 +551,12 @@ public class XMLJ2eeUtils {
     /** This method adds the element specified by elementName and elementValue into the element
      * specified by the elementPath
      * @param root Root element of the DOM graph 
      * @param elementPath List defining the element path to the target element
      * @param elementName name of the new Element
-     * @param elementValue value of te new Element
-     * @return true if method was succesful, false otherwise
+     * @param elementValue value of the new Element
+     * @return true if method was successful, false otherwise
      */ 
-    public static boolean addStringElement (Element root, List elementPath, String elementName, String elementValue){
+    public static boolean addStringElement (Element root, List<ElementAttrInfo> elementPath, String elementName, String elementValue){
         Iterator<ElementAttrInfo> it = elementPath.iterator();
         Element element = root;
         
@@ -622,13 +626,13 @@ public class XMLJ2eeUtils {
     
     /** This method deletes the all elements specified by elementName from the DOM tree
      * @param root Root element of the DOM graph 
      * @param elementPath List defining the element path to the parent element 
      * @param elementName String specifying the elements for deleting 
-     * @return true if method was succesful, false otherwise
+     * @return true if method was successful, false otherwise
      */    
-    public static boolean deleteAllElements (Element root, List elementPath, String elementName)
+    public static boolean deleteAllElements (Element root, List<ElementAttrInfo> elementPath, String elementName)
     throws org.w3c.dom.DOMException {
-        if (elementPath.size()==0) return false;
+        if (elementPath.isEmpty()) return false;
         Iterator<ElementAttrInfo> it = elementPath.iterator();
         Element parent = null;
         Element element = root;
@@ -289,14 +290,15 @@ public class XMLJ2eeUtils {
     /** This method updates the attribute specified by the elementPath in DOM tree
      * @param root Root element of the DOM graph 
-     * @param elementPath List defining the element path to the target element 
+     * @param elementPath List of ElementAttrInfo that defines the element path to the target element
      * @param attrName Attribute name of the target attribute 
      * @param attrValue New value for the attribute defined by attrName
@@ -393,15 +395,16 @@ public class XMLJ2eeUtils {
     /** This method deletes the element specified by elementPath from the DOM tree
      * @param root Root element of the DOM graph 
-     * @param elementPath List defining the element path to the target element 
-     * @return true if method was succesful, false otherwise
+     * @param elementPath List of ElementAttrInfo that defines the element path to the target element
+     * @return true if method was successful, false otherwise
      */    
@@ -449,17 +452,18 @@ public class XMLJ2eeUtils {
      * specified by the elementPath
      * @param root Root element of the DOM graph 
-     * @param elementPath List defining the element path to the target element
+     * @param elementPath List of ElementAttrInfo that defines the element path to the target element
      * @param elementName name of the new Element
      * @param keyAttribute key Attribute of the new Element
@@ -547,12 +551,12 @@ public class XMLJ2eeUtils {
      * specified by the elementPath
      * @param root Root element of the DOM graph 
-     * @param elementPath List defining the element path to the target element
+     * @param elementPath List of ElementAttrInfo that defines the element path to the target element
      * @param elementName name of the new Element
@@ -622,13 +626,13 @@ public class XMLJ2eeUtils {
     /** This method deletes the all elements specified by elementName from the DOM tree
      * @param root Root element of the DOM graph 
-     * @param elementPath List defining the element path to the parent element 
+     * @param elementPath List of ElementAttrInfo that defines the element path to the parent element
      * @param elementName String specifying the elements for deleting 